@@ -1,39 +1,39 @@
 #' Get citations in various formats from CrossRef.
-#' 
+#'
 #' @export
-#' 
+#'
 #' @param dois Search by a single DOI or many DOIs.
-#' @param format Name of the format. One of "rdf-xml", "turtle", 
-#'   "citeproc-json", "citeproc-json-ish", "text", "ris", "bibtex" (default), 
-#'   "crossref-xml", "datacite-xml","bibentry", or "crossref-tdm". The format 
+#' @param format Name of the format. One of "rdf-xml", "turtle",
+#'   "citeproc-json", "citeproc-json-ish", "text", "ris", "bibtex" (default),
+#'   "crossref-xml", "datacite-xml","bibentry", or "crossref-tdm". The format
 #'   "citeproc-json-ish" is a format that is not quite proper citeproc-json
-#' @param style a CSL style (for text format only). See \code{\link{get_styles}}
+#' @param style a CSL style (for text format only). See [get_styles()]
 #'   for options. Default: apa. If there's a style that CrossRef doesn't support
-#'   you'll get a  \code{(500) Internal Server Error}
-#' @param locale Language locale. See \code{?Sys.getlocale}
-#' @param raw (logical) Return raw text in the format given by \code{format} 
-#'   parameter. Default: FALSE
+#'   you'll get a  `(500) Internal Server Error`
+#' @param locale Lansguage locale. See `?Sys.getlocale`
+#' @param raw (logical) Return raw text in the format given by `format`
+#'   parameter. Default: `FALSE`
 #' @template moreargs
-#' @details See \url{http://citation.crosscite.org/docs.html} for more info 
+#' @details See <http://citation.crosscite.org/docs.html> for more info
 #' on the Crossref Content Negotiation API service.
-#'   
-#'   DataCite DOIs: Some values of the \code{format} parameter won't work with 
-#'   DataCite DOIs, i.e. "citeproc-json", "crossref-xml", "crossref-tdm", 
-#'     "onix-xml". 
-#'   
-#'   MEDRA DOIs only work with "rdf-xml", "turtle", "citeproc-json-ish", "ris", 
+#'
+#'   DataCite DOIs: Some values of the `format` parameter won't work with
+#'   DataCite DOIs, i.e. "citeproc-json", "crossref-xml", "crossref-tdm",
+#'     "onix-xml".
+#'
+#'   MEDRA DOIs only work with "rdf-xml", "turtle", "citeproc-json-ish", "ris",
 #'   "bibtex", "bibentry", "onix-xml".
-#'   
+#'
 #'   See examples below.
-#'   
-#'   See \code{\link{cr_agency}}
-#'   
-#'   Note that the format type \code{citeproc-json} uses the CrossRef API at 
-#'   \code{api.crossref.org}, while all others are content negotiated via
-#'   \code{http://data.crossref.org}, \code{http://data.datacite.org} or 
-#'   \code{http://data.medra.org}. DOI agency is checked first (see 
-#'   \code{\link{cr_agency}}). 
-#'   
+#'
+#'   See [cr_agency()]
+#'
+#'   Note that the format type `citeproc-json` uses the CrossRef API at
+#'   `api.crossref.org`, while all others are content negotiated via
+#'   `http://data.crossref.org`, `http://data.datacite.org` or
+#'   `http://data.medra.org`. DOI agency is checked first (see
+#'   [cr_agency()]).
+#'
 #' @examples \dontrun{
 #' cr_cn(dois="10.1126/science.169.3946.635")
 #' cr_cn(dois="10.1126/science.169.3946.635", "citeproc-json")
@@ -41,11 +41,11 @@
 #' cr_cn("10.1126/science.169.3946.635", "rdf-xml")
 #' cr_cn("10.1126/science.169.3946.635", "crossref-xml")
 #' cr_cn("10.1126/science.169.3946.635", "text")
-#' 
+#'
 #' # return an R bibentry type
 #' cr_cn("10.1126/science.169.3946.635", "bibentry")
 #' cr_cn("10.6084/m9.figshare.97218", "bibentry")
-#' 
+#'
 #' # return an apa style citation
 #' cr_cn("10.1126/science.169.3946.635", "text", "apa")
 #' cr_cn("10.1126/science.169.3946.635", "text", "harvard3")
@@ -53,11 +53,11 @@
 #' cr_cn("10.1126/science.169.3946.635", "text", "ecoscience")
 #' cr_cn("10.1126/science.169.3946.635", "text", "heredity")
 #' cr_cn("10.1126/science.169.3946.635", "text", "oikos")
-#' 
+#'
 #' # example with many DOIs
 #' dois <- cr_r(2)
 #' cr_cn(dois, "text", "apa")
-#' 
+#'
 #' # Cycle through random styles - print style on each try
 #' stys <- get_styles()
 #' foo <- function(x){
@@ -65,7 +65,7 @@
 #'  cat(cr_cn("10.1126/science.169.3946.635", "text", style=x))
 #' }
 #' foo(sample(stys, 1))
-#' 
+#'
 #' # Using DataCite DOIs
 #' ## some formats don't work
 #' # cr_cn("10.5284/1011335", "text")
@@ -79,55 +79,55 @@
 #' cr_cn("10.5284/1011335", "ris")
 #' cr_cn("10.5284/1011335", "bibtex")
 #' cr_cn("10.5284/1011335", "bibentry")
-#' 
+#'
 #' dois <- c('10.5167/UZH-30455','10.5167/UZH-49216','10.5167/UZH-503',
 #'           '10.5167/UZH-38402','10.5167/UZH-41217')
 #' cat(cr_cn(dois[1]))
 #' cat(cr_cn(dois[2]))
 #' cat(cr_cn(dois[3]))
 #' cat(cr_cn(dois[4]))
-#' 
+#'
 #' # Using Medra DOIs
 #' cr_cn("10.3233/ISU-150780", "onix-xml")
-#' 
+#'
 #' # Get raw output
 #' cr_cn(dois = "10.1002/app.27716", format = "citeproc-json", raw = TRUE)
-#' 
+#'
 #' # sometimes messy DOIs even work
 #' ## in this case, a DOI minting agency can't be found
 #' ## but we proceed anyway, just assuming it's "crossref"
 #' cr_cn("10.1890/0012-9615(1999)069[0569:EDILSA]2.0.CO;2")
 #' }
 
-`cr_cn` <- function(dois, format = "bibtex", style = 'apa', 
-                    locale = "en-US", raw = FALSE, .progress="none", ...) {
-  
+`cr_cn` <- function(dois, format = "bibtex", style = 'apa',
+                    locale = "en-US", raw = FALSE, .progress = "none", ...) {
+
   format <- match.arg(format, c("rdf-xml", "turtle", "citeproc-json",
-                                "citeproc-json-ish", "text", "ris", "bibtex", 
-                                "crossref-xml", "datacite-xml", "bibentry", 
+                                "citeproc-json-ish", "text", "ris", "bibtex",
+                                "crossref-xml", "datacite-xml", "bibentry",
                                 "crossref-tdm", "onix-xml"))
 
   cn <- function(doi, ...){
     agency_id <- suppressWarnings(GET_agency_id(doi))
     if (is.null(agency_id)) {
-      warning(doi, " agency not found - proceeding with 'crossref' ...", 
+      warning(doi, " agency not found - proceeding with 'crossref' ...",
               call. = FALSE)
       agency_id <- "crossref"
     }
-    
+
     url <- paste0("http://data.", agency_id, ".org/", doi)
-    
+
     # check cn data provider
     if (!format %in% supported_cn_types[[agency_id]]) {
-      stop(paste0("Format '", format, "' for '", doi, 
+      stop(paste0("Format '", format, "' for '", doi,
                   "' is not supported by the DOI registration agency: '",
-                  agency_id, "'.\nTry one of the following formats: ", 
+                  agency_id, "'.\nTry one of the following formats: ",
                   paste0(supported_cn_types[[agency_id]], collapse = ", ")))
     }
     pick <- c(
            "rdf-xml" = "application/rdf+xml",
            "turtle" = "text/turtle",
-           "citeproc-json" = 
+           "citeproc-json" =
              "transform/application/vnd.citationstyles.csl+json",
            "citeproc-json-ish" = "application/vnd.citationstyles.csl+json",
            "text" = "text/x-bibliography",
@@ -140,16 +140,27 @@
            "onix-xml" = "application/vnd.medra.onixdoi+xml")
     type <- pick[[format]]
     if (format == "citeproc-json") {
-      response <- GET(file.path("http://api.crossref.org/works", doi, type), 
-                      make_rcrossref_ua(), ...)
+      cli <- crul::HttpClient$new(
+        url = file.path("http://api.crossref.org/works", doi, type),
+        headers = list(
+          `User-Agent` = rcrossref_ua(), `X-USER-AGENT` = rcrossref_ua()
+        )
+      )
+      response <- cli$get(...)
     } else {
       if (format == "text") {
-        type <- paste(type, "; style = ", style, "; locale = ", locale, 
+        type <- paste(type, "; style = ", style, "; locale = ", locale,
                       sep = "")
       }
-      response <- GET(url, ..., 
-                      make_rcrossref_ua(),
-                      add_headers(Accept = type, followlocation = TRUE))
+      cli <- crul::HttpClient$new(
+        url = url,
+        opts = list(followlocation = 1),
+        headers = list(
+          `User-Agent` = rcrossref_ua(), `X-USER-AGENT` = rcrossref_ua(),
+          Accept = type
+        )
+      )
+      response <- cli$get(...)
     }
     warn_status(response)
     if (response$status_code < 202) {
@@ -168,9 +179,9 @@
         "onix-xml" = "text/xml")
       parser <- select[[format]]
       if (raw) {
-        ct_utf8(response)
+        response$parse("UTF-8")
       } else {
-        out <- ct_utf8(response)
+        out <- response$parse("UTF-8")
         if (format == "text") {
           out <- gsub("\n", "", out)
         }
@@ -193,7 +204,7 @@
       out <- try(cn(z, ...), silent = TRUE)
       if ("try-error" %in% class(out)) {
         warning(
-          paste0("Failure in resolving '", z, 
+          paste0("Failure in resolving '", z,
                  "'. See error detail in results."),
           call. = FALSE
         )
@@ -216,20 +227,20 @@ parse_bibtex <- function(x){
 
 warn_status <- function(x) {
   if (x$status_code > 202) {
-    mssg <- ct_utf8(x)
+    mssg <- x$parse("UTF-8")
     if (!is.character(mssg)) {
       mssg <- if (x$status_code == 406) {
         "(406) - probably bad format type"
       } else {
-        http_status(x)$message
+        x$status_http()$message
       }
     } else {
       mssg <- paste(sprintf("(%s)", x$status_code), "-", mssg)
     }
     warning(
       sprintf(
-        "%s w/ %s", 
-        gsub("%2F", "/", httr::parse_url(x$url)$path), 
+        "%s w/ %s",
+        gsub("%2F", "/", crul::url_parse(x$url)$path),
         mssg
       ),
       call. = FALSE
@@ -238,7 +249,7 @@ warn_status <- function(x) {
 }
 
 #' Get doi agency id to identify resource location
-#' 
+#'
 #' @param x doi
 #' @keywords internal
 GET_agency_id <- function(x, ...) {
@@ -251,11 +262,11 @@ GET_agency_id <- function(x, ...) {
 # Supported content types
 # See http://www.crosscite.org/cn/
 supported_cn_types <- list(
-  crossref = c("rdf-xml", "turtle", "citeproc-json", "citeproc-json-ish", 
-               "text", "ris", "bibtex", "crossref-xml", "bibentry", 
+  crossref = c("rdf-xml", "turtle", "citeproc-json", "citeproc-json-ish",
+               "text", "ris", "bibtex", "crossref-xml", "bibentry",
                "crossref-tdm"),
   datacite = c("rdf-xml", "turtle", "datacite-xml", "citeproc-json-ish", "text",
                "ris", "bibtex", "bibentry"),
-  medra = c("rdf-xml", "turtle", "citeproc-json-ish", "ris", "bibtex", 
+  medra = c("rdf-xml", "turtle", "citeproc-json-ish", "ris", "bibtex",
             "bibentry", "onix-xml")
 )
