@@ -86,7 +86,8 @@ filter_list <- c(
   'archive','has_orcid','orcid','issn','type','directory','doi','updates','is_update',
   'has_update_policy','container_title','publisher_name','category_name','type_name',
   'from_created_date', 'until_created_date', 'affiliation', 'has_affiliation',
-  'assertion_group', 'assertion', 'article_number', 'alternative_id'
+  'assertion_group', 'assertion', 'article_number', 'alternative_id',
+  'has-clinical-trial-number', 'has-abstract'
 )
 
 filter_deets <- list(
@@ -135,5 +136,7 @@ filter_deets <- list(
   "affiliation" = list("possible_values" = NA, "description" = "metadata for records with at least one contributor with the given affiliation" ),
   "has_affiliation" = list("possible_values" = NA, "description" = "metadata for records that have any affiliation information" ),
   "article_number" = list("possible_values" = NA, "description" = "metadata for records with a given article number"),
-  "alternative_id" = list("possible_values" = NA, "description" = "metadata for records with the given alternative ID, which may be a publisher_specific ID, or any other identifier a publisher may have provided")
+  "alternative_id" = list("possible_values" = NA, "description" = "metadata for records with the given alternative ID, which may be a publisher_specific ID, or any other identifier a publisher may have provided"),
+  'has_clinical_trial_number' = list("possible_values" = NA, "description" = "metadata for records which include a clinical trial number"), 
+  'has_abstract' = list("possible_values" = NA, "description" = "metadata for records which include an abstract")
 )
