@@ -4,7 +4,8 @@
 #' @rdname pmid2doi-defunct
 #' @keywords internal
 `pmid2doi` <- function(...){
-  .Defunct(msg = "The web API behind this function is down indefinitely, see id_converter()")
+  .Defunct(msg = "The web API behind this function is down indefinitely, 
+           see id_converter()")
 }
 
 #' @export
