@@ -1,9 +1,6 @@
 cr_compact <- function(x) Filter(Negate(is.null), x)
 
-ct_utf8 <- function(x) httr::content(x, as = "text", encoding = "UTF-8")
-
 asl <- function(z) {
-  # z <- tolower(z)
   if (is.logical(z) || tolower(z) == "true" || tolower(z) == "false") {
     if (z) {
       return('true')
@@ -15,46 +12,54 @@ asl <- function(z) {
   }
 }
 
-make_rcrossref_ua <- function() {
-  c(
-    httr::user_agent(rcrossref_ua()),
-    httr::add_headers(`X-USER-AGENT` = rcrossref_ua())
-  )
-}
-
 rcrossref_ua <- function() {
   versions <- c(paste0("r-curl/", utils::packageVersion("curl")),
-                paste0("httr/", utils::packageVersion("httr")),
-                sprintf("rOpenSci(rcrossref/%s)", utils::packageVersion("rcrossref")))
+                paste0("crul/", utils::packageVersion("crul")),
+                sprintf("rOpenSci(rcrossref/%s)", 
+                        utils::packageVersion("rcrossref")))
   paste0(versions, collapse = " ")
 }
 
 cr_GET <- function(endpoint, args, todf = TRUE, on_error = warning, parse = TRUE, ...) {
-  url <- sprintf("http://api.crossref.org/%s", endpoint)
+  url <- sprintf("https://api.crossref.org/%s", endpoint)
+  cli <- crul::HttpClient$new(
+    url = url,
+    headers = list(
+      `User-Agent` = rcrossref_ua(),
+      `X-USER-AGENT` = rcrossref_ua()
+    )
+  )
   if (length(args) == 0) {
-    res <- GET(url, make_rcrossref_ua(), ...)
+    res <- cli$get(...)
   } else {
-    res <- GET(url, query = args, make_rcrossref_ua(), ...)
+    res <- cli$get(query = args, ...)
   }
   doi <- gsub("works/|/agency|funders/", "", endpoint)
   if (!res$status_code < 300) {
     on_error(sprintf("%s: %s - (%s)", res$status_code, get_err(res), doi), call. = FALSE)
     list(message = NULL)
   } else {
-    stopifnot(res$headers$`content-type` == "application/json;charset=UTF-8")
-    res <- ct_utf8(res)
+    stopifnot(res$response_headers$`content-type` == "application/json;charset=UTF-8")
+    res <- res$parse("UTF-8")
     if (parse) jsonlite::fromJSON(res, todf) else res
   }
 }
 
 get_err <- function(x) {
-  xx <- ct_utf8(x)
-  if (x$headers$`content-type` == "text/plain") {
+  xx <- x$parse("UTF-8")
+  if (is.null(x$response_headers$`content-type`)) {
+    rr <- tryCatch(jsonlite::fromJSON(xx), error = function(e) e)
+    if (inherits(rr, "error")) {
+      tmp <- xx
+    } else {
+      tmp <- rr$message$description
+    }
+  } else if (x$response_headers$`content-type` == "text/plain") {
     tmp <- xx
-  } else if (x$headers$`content-type` == "text/html") {
+  } else if (x$response_headers$`content-type` == "text/html") {
     html <- xml2::read_html(xx)
-    tmp <- xml2::xml_text(xml2::xml_find_one(html, '//h3[@class="info"]'))
-  } else if (x$headers$`content-type` == "application/json;charset=UTF-8") {
+    tmp <- xml2::xml_text(xml2::xml_find_first(html, '//h3[@class="info"]'))
+  } else if (x$response_headers$`content-type` == "application/json;charset=UTF-8") {
     tmp <- jsonlite::fromJSON(xx, FALSE)
   } else {
     tmp <- xx
@@ -134,7 +139,10 @@ prep_args <- function(query, filter, offset, limit, sample, sort,
   check_number(sample)
   filter <- filter_handler(filter)
   flq <- field_query_handler(flq)
-  facet <- if (facet) "t" else NULL
+  stopifnot(class(facet) %in% c('logical', 'character'))
+  if (inherits(facet, "logical")) {
+    facet <- if (facet) "t" else NULL
+  }
   cr_compact(
     c(
       list(query = query, filter = filter, offset = offset, rows = limit,
